@@ -1,6 +1,7 @@
 #' Get the number of levels for each factor used in `xlevels`
 #'
-#' @param model a model object
+#' @param model (a model object, e.g. `glm`)\cr
+#' A model object.
 #' @return a tibble with two columns: `"variable"` and `"var_nlevels"`
 #' @export
 #' @family model_helpers
@@ -26,3 +27,9 @@ model_get_nlevels.default <- function(model) {
     var_nlevels = unlist(nlevels)
   )
 }
+
+#' @export
+#' @rdname model_get_nlevels
+model_get_nlevels.svy_vglm <- function(model) {
+  model_get_nlevels(model$fit)
+}
