@@ -8,13 +8,17 @@
 #' is kept in a new column `original_term`.
 #'
 #'
-#' @param x a tidy tibble
-#' @param sep character, separator added between group name and term
-#' @param model the corresponding model, if not attached to `x`
+#' @param x (`data.frame`)\cr
+#' A tidy tibble as produced by `tidy_*()` functions.
+#' @param sep (`string`)\cr
+#' Separator added between group name and term.
+#' @param model (a model object, e.g. `glm`)\cr
+#' The corresponding model, if not attached to `x`.
 #' @inheritParams tidy_plus_plus
 #' @export
 #' @family tidy_helpers
-#' @examplesIf interactive()
+#' @examples
+#' \donttest{
 #' if (
 #'   .assert_package("lme4", boolean = TRUE) &&
 #'     .assert_package("broom.mixed", boolean = TRUE) &&
@@ -25,6 +29,7 @@
 #'     tidy_and_attach() |>
 #'     tidy_disambiguate_terms()
 #' }
+#' }
 tidy_disambiguate_terms <- function(x, sep = ".", model = tidy_get_model(x), quiet = FALSE) {
   if (is.null(model)) {
     cli::cli_abort(c(
@@ -37,7 +42,10 @@ tidy_disambiguate_terms <- function(x, sep = ".", model = tidy_get_model(x), qui
       !quiet &&
         !inherits(model, "LORgee") && # no alert for multgee models
         !inherits(model, "zeroinfl") && # or zeroninfl/hurdle
-        !inherits(model, "hurdle")
+        !inherits(model, "hurdle") &&
+        !inherits(model, "vgam") && # vgam models
+        !inherits(model, "vglm") &&
+        !inherits(model, "svy_vglm")
     ) {
       cli_alert_danger(paste(
         "{.code tidy_disambiguate_terms()} has already been applied.",
