@@ -699,12 +699,18 @@ test_that("tidy_plus_plus() works with fixest models", {
   skip_if_not_installed("fixest")
   skip_if(compareVersion(as.character(getRversion()), "4.1") < 0)
 
+  data("mtcars")
   mod <- fixest::feols(fml = mpg ~ am + factor(carb), data = mtcars)
   expect_no_error(
     res <- mod |> tidy_plus_plus()
   )
 
-  mod <- fixest::feglm(Sepal.Length ~ Sepal.Width + Petal.Length | Species, iris, "poisson")
+  data("iris")
+  mod <- fixest::feglm(
+    Sepal.Length ~ Sepal.Width + Petal.Length | Species,
+    iris,
+    "poisson"
+  )
   expect_no_error(
     res <- mod |> tidy_plus_plus()
   )
@@ -720,11 +726,10 @@ test_that("tidy_plus_plus() works with fixest models", {
   res <- mod |> tidy_plus_plus(instrumental_suffix = " (IV)")
   expect_equal(res$var_label[res$term == "wt"], "wt (IV)", ignore_attr = TRUE)
 
-  mod <- fixest::feols(mpg ~ disp | 1 | factor(cyl) ~ qsec, data = mtcars)
+  mod <- fixest::feols(mpg ~ cyl, data = mtcars[mtcars$carb != 1, ])
   expect_no_error(
     res <- mod |> tidy_plus_plus()
   )
-  expect_equal(nrow(res[res$instrumental, ]), 3L)
 })
 
 test_that("tidy_plus_plus() works with logitr models", {
@@ -986,3 +991,28 @@ test_that("tidy_plus_plus() works with glmtoolbox::glmgee() models", {
   )
   expect_equal(nrow(res), 6)
 })
+
+test_that("tidy_plus_plus() works with quantreg::rq() models", {
+  skip_on_cran()
+  skip_if_not_installed("quantreg")
+
+  data("stackloss", package = "datasets")
+
+  mod <- quantreg::rq(
+    stack.loss ~ stack.x,
+    tau  = .5
+  )
+  expect_no_error(
+    res <- mod |> tidy_plus_plus()
+  )
+  expect_equal(nrow(res), 3)
+
+  mod <- quantreg::rq(
+    stack.loss ~ stack.x,
+    tau  = 1:3 / 4
+  )
+  expect_no_error(
+    res <- mod |> tidy_plus_plus(intercept = TRUE)
+  )
+  expect_equal(nrow(res), 12)
+})
